;; color-mate-fontset-meadow.el fontset definition file for Meadow

;; Copyright (C) YOKOTA Hiroshi

;; Author: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>
;; Maintainer: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>
;; Version: 10.4
;; Keywords: color color-mate
;; Content-Type: text/plain; charset=x-euc-jp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Color-Mate  Ver.10.4
;;         by 横田 裕思 (yokota@netlab.is.tsukuba.ac.jp)
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Coloring mule/emacs to more easier and more fun.
;;   mule / emacs で、色を使用して見やすい画面にします。
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; This file is part of Color-Mate

;; $Id: color-mate-fontset-meadow.el,v 10.3 2001/03/16 04:54:40 elca Exp $

;; must requires Emacs fontset
(require 'color-mate-fontset-emacs)

(create-fontset-from-request
  "fontset-12"
  '((width  . 6)
    (height . 12)
    (fixed  . t)
    (italic . nil))
  '((family . "Courier")
    (family . "ＭＳ ゴシック")))

(create-fontset-from-request
  "fontset-14"
  '((width  . 7)
    (height . 14)
    (fixed  . t)
    (italic . nil))
  '((family . "Courier")
    (family . "ＭＳ ゴシック")))

(create-fontset-from-request
  "fontset-16"
  '((width  . 8)
    (height . 16)
    (fixed  . t)
    (italic . nil))
  '((family . "Courier")
    (family . "ＭＳ ゴシック")))

(create-fontset-from-request
  "fontset-24"
  '((width  . 12)
    (height . 24)
    (fixed  . t)
    (italic . nil))
  '((family . "Courier")
    (family . "ＭＳ ゴシック")))

(provide 'color-mate-fontset-meadow)

;; color-mate-fontset-meadow.el ends here
